from roboflowoak.pipe import DepthAIPipeline, list_devices
from roboflowoak.api import download_blob
import os
import json
import threading
from pip._internal.utils.appdirs import user_cache_dir
import shutil

cache_dir = user_cache_dir("pip") + "/roboflow"


class RoboflowOak:
    def __init__(
        self,
        model,
        version,
        api_key,
        confidence=0.2,
        overlap=0.5,
        advanced_config={},
        rgb=False,
        depth=False,
        device=None,
        device_name="device",
        blocking=True,
        legacy=False,
        api_endpoint="https://api.roboflow.com",
    ):
        self.project = model
        self.version = version
        self.api_key = api_key
        self.blocking = blocking
        self.depth = depth
        self.confidence = confidence
        self.overlap = overlap
        self.device_name = device_name
        self.dev = device
        self.api_endpoint = api_endpoint
        self.advanced_config = advanced_config
        self.fast = not len(self.advanced_config.keys()) > 0
        self.sensor_mode = "THE_1080_P"
        self.wide_fov = False
        self.night_vision = False
        if "sensor_mode" in self.advanced_config.keys():
            self.sensor_mode = advanced_config["sensor_mode"]
        if "wide_fov" in self.advanced_config.keys():
            self.wide_fov = advanced_config["wide_fov"]
        if "night_vision" in self.advanced_config.keys():
            self.night_vision = advanced_config["night_vision"]

        if self.dev is None:
            available_devices = list_devices()
            if len(available_devices) == 0:
                raise Exception("No available OAK devices detected.")
                default_device = None
            else:
                self.dev = available_devices[0]

        self.cache_path = self.find_weights()
        with open(os.path.join(self.cache_path, "config.txt"), "r") as f:
            self.model_objects = json.loads(f.read())
            self.size = (
                int(self.model_objects["environment"]["RESOLUTION"]),
                int(self.model_objects["environment"]["RESOLUTION"]),
            )
            self.resolution = self.size
            self.class_names = self.model_objects["class_names"]
            self.colors = self.model_objects["colors"]
            self.modelType = self.model_objects.get("modelType", "yolov5")
            # print("Size",self.size,"Resolution",self.resolution)
        try:
            self.dai_pipe = DepthAIPipeline(
                self.cache_path + "/roboflow.blob",
                self.size,
                self.resolution,
                self.class_names,
                rgb,
                self.colors,
                self.fast,
                self.confidence,
                self.overlap,
                self.sensor_mode,
                self.wide_fov,
                depth,
                device,
                legacy,
                    self.night_vision,
                self.modelType,
            )
        except:
            try:
                shutil.rmtree(cache_dir)
                self.cache_path = self.find_weights()
                with open(os.path.join(self.cache_path, "config.txt"), "r") as f:
                    self.model_objects = json.loads(f.read())
                    self.size = (
                        int(self.model_objects["environment"]["RESOLUTION"]),
                        int(self.model_objects["environment"]["RESOLUTION"]),
                    )
                    self.resolution = self.size
                    self.class_names = self.model_objects["class_names"]
                    self.colors = self.model_objects["colors"]
                    self.modelType = self.model_objects.get("modelType", "yolov5")
                self.dai_pipe = DepthAIPipeline(
                    self.cache_path + "/roboflow.blob",
                    self.size,
                    self.resolution,
                    self.class_names,
                    rgb,
                    self.colors,
                    self.fast,
                    self.confidence,
                    self.overlap,
                    self.sensor_mode,
                    self.wide_fov,
                    depth,
                    device,
                    legacy,
                    self.night_vision,
                    self.modelType,
                )
            except:
                raise Exception(
                    "Failure while retrying load weights - does this model, version, api key exist? can you curl api.roboflow.com, and can your device download files from google cloud storage? have you hit your device limit?"
                )

    def find_weights(self):
        if os.path.exists(
            os.path.join(cache_dir, self.project, self.version, "roboflow.blob")
        ) and os.path.exists(
            os.path.join(cache_dir, self.project, self.version, "config.txt")
        ):
            return os.path.join(cache_dir, self.project, self.version)

        return download_blob(
            self.project, self.version, self.api_key, self.dev, self.api_endpoint
        )

    def detect(self):
        ret = self.dai_pipe.get()

        predictions = []
        dets = ret[0]
        for det in dets:
            if len(det) > 6:
                predictions.append(
                    Prediction(
                        (det[0] + det[2]) / 2,
                        (det[1] + det[3]) / 2,
                        det[2] - det[0],
                        det[3] - det[1],
                        det[5],
                        det[4],
                        det[6],
                    )
                )
            else:
                predictions.append(
                    Prediction(
                        (det[0] + det[2]) / 2,
                        (det[1] + det[3]) / 2,
                        det[2] - det[0],
                        det[3] - det[1],
                        det[5],
                        det[4],
                    )
                )

        ret = list(ret)
        ret[0] = {"predictions": predictions}
        return ret

    def camera_control(self, control):
        self.dai_pipe.camera_control(control)


class OAKThread(threading.Thread, RoboflowOak):
    def __init__(
        self,
        threadID,
        name,
        counter,
        onDetect,
        project,
        version,
        api_key,
        confidence=0.5,
        overlap=0.5,
        advanced_config={},
        rgb=True,
        depth=False,
        device=None,
        device_name="device",
        blocking=True,
        legacy=False,
    ):
        RoboflowOak.__init__(
            self,
            project,
            version,
            api_key,
            confidence,
            overlap,
            advanced_config,
            rgb,
            depth,
            device,
            device_name,
            blocking,
            legacy,
        )
        threading.Thread.__init__(self)
        self.threadID = threadID
        self.name = name
        self.counter = counter
        self.onDetect = onDetect

    def run(self):
        while True:
            detections, frame, raw_frame, depth = self.detections()
            self.onDetect(self.threadID, detections, frame, raw_frame, depth)


def devices():
    return list_devices()


class Prediction:
    def __init__(self, x, y, width, height, confidence, class_name, depth=None):
        self.x = x
        self.y = y
        self.width = width
        self.height = height
        self.depth = depth
        self.confidence = confidence
        self.class_name = class_name

    def json(self):
        return {
            "x": self.x,
            "y": self.y,
            "width": self.width,
            "height": self.height,
            "depth": self.depth,
            "confidence": self.confidence,
            "class": self.class_name,
        }



import requests
import os
import json
from pip._internal.utils.appdirs import user_cache_dir

cache_dir = user_cache_dir("pip") + "/roboflow"


def download_blob(project, version, api_key, device_id, api_endpoint):
    endpoint = (
        api_endpoint
        + "/oak/"
        + project
        + "/"
        + version
        + "?api_key="
        + api_key
        + "&device="
        + device_id
        + "&nocache=true"
    )
    api_data = requests.get(endpoint)

    if api_data.status_code != 200:
        raise Exception(str(api_data.json()))
    api_data = api_data.json()
    if "warning" in api_data.keys():
        print(api_data["warning"], flush=True)

    model_objects = {}
    model_objects["class_names"] = api_data["oak"]["classes"]
    model_objects["colors"] = api_data["oak"]["colors"]
    model_objects["environment"] = requests.get(api_data["oak"]["environment"]).json()
    model_objects["modelType"] = api_data["oak"]["modelType"]
    r = requests.get(api_data["oak"]["model"])
    try:
        os.makedirs(os.path.join(cache_dir, project, version))
    except OSError as error:
        print(error)
    with open(os.path.join(cache_dir, project, version, "roboflow.blob"), "wb") as f:
        f.write(r.content)
    with open(os.path.join(cache_dir, project, version, "config.txt"), "w") as f:
        f.write(json.dumps(model_objects))

    return os.path.join(cache_dir, project, version)



import depthai as dai
import numpy as np
import cv2
import roboflowoak.postprocs as postprocs
import threading


class DepthAIPipeline:
    def __init__(
        self,
        nn_path,
        size,
        resolution,
        class_names,
        cam_stream,
        colors,
        fast=True,
        confidence=0.5,
        overlap=0.5,
        sensor_mode="THE_1080_P",
        stretch=False,
        depth=False,
        device=None,
        legacy=False,
        night_vision=False,
        modelType="yolov5",
    ):
        self.nn_path = nn_path
        self.size = size
        self.class_names = class_names
        self.cam_stream = cam_stream
        self.colors = colors
        self.fast = fast
        self.stretch = stretch
        self.resolution = resolution
        self.dev = device
        self.depth = depth
        self.overlap = overlap
        self.confidence = confidence
        self.night_vision = night_vision
        self.frames = {}
        self.post_processing = (
            self.post_processing_yolov8
            if "yolov8" in modelType
            else self.post_processing_yolov5
        )

        self.pipeline = dai.Pipeline()
        if legacy:
            self.pipeline.setOpenVINOVersion(dai.OpenVINO.Version.VERSION_2021_1)

        self.cam_rgb = self.pipeline.create(dai.node.ColorCamera if not self.night_vision else dai.node.MonoCamera)
        self.cam_rgb.setBoardSocket(dai.CameraBoardSocket.RGB if not self.night_vision else dai.CameraBoardSocket.LEFT)
        #self.cam_rgb.setColorOrder(dai.ColorCameraProperties.ColorOrder.RGB)

        self.xout_raw = self.pipeline.create(dai.node.XLinkOut)
        self.xout_raw.setStreamName("raw")
        self.xout_raw.input.setBlocking(False)
        self.xout_raw.input.setQueueSize(1)

        self.controlIn = self.pipeline.create(dai.node.XLinkIn)
        self.controlIn.setStreamName("control")
        self.controlIn.out.link(self.cam_rgb.inputControl)

        self.detection_nn = self.pipeline.createNeuralNetwork()
        try:
            self.detection_nn.setBlobPath(self.nn_path)
        except:
            raise Exception("Failure loading model...")

        if cam_stream:
            self.xout_rgb = self.pipeline.createXLinkOut()
            self.xout_rgb.setStreamName("rgb")
            # self.cam_rgb.video.link(self.xout_rgb.input)

        self.xout_nn = self.pipeline.createXLinkOut()
        self.xout_nn.setStreamName("nn")
        self.detection_nn.out.link(self.xout_nn.input)

        self.manip_out = self.pipeline.createXLinkOut()
        self.manip_out.setStreamName("manip")

        if self.fast:
            # self.cam_rgb.setResolution(getattr(dai.ColorCameraProperties.SensorResolution, "THE_720_P"))
            self.cam_rgb.setPreviewSize(self.size)
            self.cam_rgb.setInterleaved(False)

            self.cam_rgb.preview.link(self.detection_nn.input)
            if cam_stream:
                self.detection_nn.passthrough.link(self.xout_raw.input)

        else:
            if night_vision:
                self.cam_rgb.setResolution(getattr(dai.MonoCameraProperties.SensorResolution, sensor_mode))
            else:
                self.cam_rgb.setResolution(getattr(dai.ColorCameraProperties.SensorResolution, sensor_mode))

            self.manip = self.pipeline.createImageManip()

            self.manip.initialConfig.setCropRect((0, 0, 1, 1))
            self.manip.initialConfig.setResize(self.size)
            self.manip.setMaxOutputFrameSize(self.size[0] * self.size[1] * 3)
            self.manip.out.link(self.manip_out.input)

            if self.stretch:
                self.manip.initialConfig.setKeepAspectRatio(False)
            # self.manip.inputImage.setBlocking(True)
            self.manip.initialConfig.setFrameType(dai.ImgFrame.Type.BGR888p)

            self.manip.out.link(self.detection_nn.input)

            if night_vision:
                self.cam_rgb.out.link(self.manip.inputImage)
            else:
                self.cam_rgb.video.link(self.manip.inputImage)

            if cam_stream:
                if night_vision:
                    self.cam_rgb.out.link(self.xout_raw.input)
                else:
                    self.cam_rgb.video.link(self.xout_raw.input)
                self.manip.out.link(self.xout_rgb.input)

        if self.depth:
            self.left = self.pipeline.create(dai.node.MonoCamera)
            self.right = self.pipeline.create(dai.node.MonoCamera)
            self.stereo = self.pipeline.create(dai.node.StereoDepth)

            self.depthOut = self.pipeline.create(dai.node.XLinkOut)

            self.depthOut.setStreamName("depth")

            monoResolution = dai.MonoCameraProperties.SensorResolution.THE_400_P
            fps = 30

            self.left.setResolution(monoResolution)
            self.left.setBoardSocket(dai.CameraBoardSocket.LEFT)
            self.right.setResolution(monoResolution)
            self.right.setBoardSocket(dai.CameraBoardSocket.RIGHT)

            self.stereo.initialConfig.setConfidenceThreshold(245)
            self.stereo.setLeftRightCheck(True)
            self.stereo.setDepthAlign(dai.CameraBoardSocket.RGB)

            self.left.out.link(self.stereo.left)
            self.right.out.link(self.stereo.right)
            self.stereo.depth.link(self.depthOut.input)

        if self.dev is None:
            available_devices = list_devices()
            if len(available_devices) == 0:
                default_device = None
            else:
                self.dev = available_devices[0]

        found, device_info = dai.Device.getDeviceByMxId(self.dev)

        if not found:
            print("Device Not Found")
        self.device = dai.Device(self.pipeline, device_info)

        if night_vision:
            # self.device.setIrLaserDotProjectorBrightness(500)
            self.device.setIrFloodLightBrightness(500)

        self.q_det = self.device.getOutputQueue(name="nn", maxSize=4, blocking=False)

        if self.depth:
            self.q_depth = self.device.getOutputQueue(
                name="depth", maxSize=4, blocking=False
            )

        if cam_stream:
            self.q_rgb = self.device.getOutputQueue(
                name="rgb", maxSize=4, blocking=False
            )
            self.q_raw = self.device.getOutputQueue(
                name="raw", maxSize=4, blocking=False
            )

        self.q_manip = self.device.getOutputQueue(
            name="manip", maxSize=4, blocking=False
        )

        if not self.fast:
            frame_thread = threading.Thread(target=collect_frame_thread, args=(self,))
            frame_thread.start()
            frame_thread2 = threading.Thread(target=collect_frame_thread, args=(self,))
            frame_thread2.start()

    def detection_depth(self, detections, depth):
        res = []
        sx = len(depth) / self.size[0]
        sy = len(depth[0]) / self.size[1]

        depth = np.nan_to_num(depth, copy=False, nan=0)

        for det in detections:
            x = (det[2] + det[0]) / 2
            y = (det[3] + det[1]) / 2
            x = int(x * sx)
            y = int(y * sy)
            d = depth[det[0] : det[2], det[1] : det[3]]
            dist = np.amin(d)
            res.append([det[0], det[1], det[2], det[3], det[4], det[5], dist])

        return res

    def camera_control(self, control):
        q_control = self.device.getInputQueue(name="control")
        q_control.send(control)

    def print_seq_nums(self):
        nums = [frame.getSequenceNum() for frame in self.frames]
        print("Current Frames: ", nums)

    def clear_earlier_frames(self, seq_num):
        self.frames = {
            key: val for key, val in self.frames.items() if int(key) >= seq_num
        }

    def find_frame(self, in_det):
        in_det_seq = in_det.getSequenceNum()
        # print("in_det seq num", in_det_seq)
        # self.print_seq_nums()
        self.clear_earlier_frames(in_det_seq)
        try:
            return self.frames[str(in_det_seq)]
        except:
            return
        # for i, frame in enumerate(self.frames):
        #    if frame.getSequenceNum() == in_det_seq:
        #        self.frames = self.frames[i:]
        #        return frame

        # if len(self.frames) > 0:
        #    return self.frames[1]

    def get(self):
        if self.depth:
            in_depth = self.q_depth.get()

        # in_manip = self.q_manip.get()

        in_det = self.q_det.get()
        detections = self.post_processing(in_det)

        depth = None

        if self.depth:
            depth = in_depth.getFrame()

            detections = self.detection_depth(detections, depth)

        if self.cam_stream:
            rgb_in = None
            if self.fast:
                rgb_in = self.q_raw.get()
            frame, frame_raw = self.process_frame(detections, in_det, rgb_in)
            return detections, frame, frame_raw, depth

        return detections, depth

    def process_frame(self, detections, in_det, in_raw):
        frame_raw = None
        if not self.fast:
            in_raw = self.find_frame(in_det)

        if not in_raw:
            return np.array([]), np.array([])

        frame = in_raw.getCvFrame()

        x_offset = int((in_raw.getWidth() - in_raw.getHeight()) / 2)
        x_max = in_raw.getWidth() - x_offset

        # frame = frame.reshape(shape)
        # frame = frame.transpose(1, 2, 0)
        frame = frame.astype(np.uint8)
        frame = np.ascontiguousarray(frame)
        if self.night_vision:
            frame = np.stack((frame,)*3, axis=-1)
        if not self.stretch:
            frame = frame[:, x_offset:x_max, :]
        frame_raw = np.array(frame)

        if frame is not None:
            for detection in self.scale_detections(
                detections, (in_raw.getWidth(), in_raw.getHeight())
            ):
                class_color = self.colors[detection[4]].strip("#")
                class_color = tuple(int(class_color[i : i + 2], 16) for i in (0, 2, 4))
                cv2.rectangle(
                    frame,
                    (detection[0], detection[1]),
                    (detection[2], detection[3]),
                    class_color,
                    2,
                )
                cv2.putText(
                    frame,
                    detection[4],
                    (detection[0] + 10, detection[1] + 20),
                    cv2.FONT_HERSHEY_TRIPLEX,
                    0.5,
                    class_color,
                )
                cv2.putText(
                    frame,
                    str(int(detection[5] * 100)) + "%",
                    (detection[0] + 10, detection[1] + 40),
                    cv2.FONT_HERSHEY_TRIPLEX,
                    0.5,
                    class_color,
                )

        return frame, frame_raw

    def scale_detections(self, detections, frame_size):
        sx = frame_size[0] / self.size[0]
        sy = frame_size[1] / self.size[1]
        if not self.stretch:
            sx = sy
        res = []
        for det in detections:
            res.append(
                [
                    int(det[0] * sx),
                    int(det[1] * sy),
                    int(det[2] * sx),
                    int(det[3] * sy),
                    det[4],
                    det[5],
                ]
            )

        return res

    def post_processing_yolov5(self, in_det):
        if in_det == None:
            return []

        in_nn_layer = in_det.getLayerFp16("output")
        num_anchor_boxes = len(np.array(in_nn_layer)) / (len(self.class_names) + 5)
        tensors = np.reshape(
            np.array(in_nn_layer), (1, int(num_anchor_boxes), len(self.class_names) + 5)
        )

        batch_detections_np = postprocs.w_np_non_max_suppression(
            tensors,
            len(self.class_names),
            conf_thres=self.confidence,
            nms_thres=self.overlap,
        )

        detections = []
        if len(batch_detections_np) == 0:
            detections = []
        else:
            detections = postprocs.process_detections(
                batch_detections_np[0],
                self.size,
                class_filter=self.class_names,
                class_names=self.class_names,
            )

        return detections

    def post_processing_yolov8(self, in_det):
        if in_det == None:
            return []
        in_nn_layer = in_det.getLayerFp16("output0")
        num_anchor_boxes = len(np.array(in_nn_layer)) / (len(self.class_names) + 4)
        tensors = np.reshape(
            np.array(in_nn_layer), (1, len(self.class_names) + 4, int(num_anchor_boxes))
        )
        tensors = np.transpose(tensors, (0, 2, 1))
        boxes = tensors[:, :, :4]
        class_confs = tensors[:, :, 4:]
        confs = np.expand_dims(np.max(class_confs, axis=2), axis=2)
        tensors = np.concatenate([boxes, confs, class_confs], axis=2)

        batch_detections_np = postprocs.w_np_non_max_suppression(
            tensors,
            len(self.class_names),
            conf_thres=self.confidence,
            nms_thres=self.overlap,
        )

        detections = []
        if len(batch_detections_np) == 0:
            detections = []
        else:
            detections = postprocs.process_detections(
                batch_detections_np[0],
                self.size,
                class_filter=self.class_names,
                class_names=self.class_names,
            )

        return detections


def collect_frame_thread(self):
    while True:
        if self.cam_stream:
            # in_rgb = self.q_rgb.get()
            in_raw = self.q_raw.get()
            self.frames[str(in_raw.getSequenceNum())] = in_raw
            # print("got frame; queue: ",len(self.frames))
        else:
            break


def list_devices():
    available_devices = []
    for device in dai.Device.getAllAvailableDevices():
        available_devices.append(device.getMxId())
    return available_devices



import numpy as np

def non_max_suppression_fast(boxes, overlapThresh):
    if len(boxes) == 0:
        return []

    if boxes.dtype.kind == "i":
        boxes = boxes.astype("float")
    pick = []
    x1 = boxes[:,0]
    y1 = boxes[:,1]
    x2 = boxes[:,2]
    y2 = boxes[:,3]
    conf = boxes[:,4]

    area = (x2 - x1 + 1) * (y2 - y1 + 1)
    idxs = np.argsort(conf)

    while len(idxs) > 0:

        last = len(idxs) - 1
        i = idxs[last]
        pick.append(i)

        xx1 = np.maximum(x1[i], x1[idxs[:last]])
        yy1 = np.maximum(y1[i], y1[idxs[:last]])
        xx2 = np.minimum(x2[i], x2[idxs[:last]])
        yy2 = np.minimum(y2[i], y2[idxs[:last]])
        w = np.maximum(0, xx2 - xx1 + 1)
        h = np.maximum(0, yy2 - yy1 + 1)
        overlap = (w * h) / area[idxs[:last]]
        idxs = np.delete(idxs, np.concatenate(([last],
            np.where(overlap > overlapThresh)[0])))

    return boxes[pick].astype("float")


def w_np_non_max_suppression(np_prediction, num_classes, conf_thres=0.5, nms_thres=0.4):
    np_box_corner = np.zeros(np_prediction.shape)
    np_box_corner[:, :, 0] = np_prediction[:, :, 0] - np_prediction[:, :, 2] / 2
    np_box_corner[:, :, 1] = np_prediction[:, :, 1] - np_prediction[:, :, 3] / 2
    np_box_corner[:, :, 2] = np_prediction[:, :, 0] + np_prediction[:, :, 2] / 2
    np_box_corner[:, :, 3] = np_prediction[:, :, 1] + np_prediction[:, :, 3] / 2

    np_prediction[:, :, :4] = np_box_corner[:, :, :4]
    batch_predictions = []
    for np_image_i, np_image_pred in enumerate(np_prediction):
        filtered_predictions = []
        np_conf_mask = (np_image_pred[:, 4] >= conf_thres).squeeze()

        np_image_pred = np_image_pred[np_conf_mask]
        if np_image_pred.shape[0] == 0:
            continue
        np_class_conf = np.max(np_image_pred[:, 5:5 + num_classes], 1)
        np_class_pred = np.argmax(np_image_pred[:, 5:5 + num_classes], 1)
        np_class_conf = np.expand_dims(np_class_conf, axis=1)
        np_class_pred = np.expand_dims(np_class_pred, axis=1)
        np_detections = np.append(np.append(np_image_pred[:, :5], np_class_conf, axis =1), np_class_pred, axis = 1)

        np_unique_labels = np.unique(np_detections[:, -1])

        for c in np_unique_labels:
            np_detections_class = np_detections[np_detections[:, -1] == c]
            np_detections_class = sorted(np_detections_class, key=lambda row: row[4], reverse=True)
            np_max_detections = []

            filtered_predictions.extend(non_max_suppression_fast(np.array(np_detections_class), nms_thres))
        batch_predictions.append(filtered_predictions)
    return batch_predictions

def scale_coords(img1_shape, coords, img0_shape, ratio_pad=None):
    if ratio_pad is None: 
        gain = max(img1_shape) / max(img0_shape)
        pad = (img1_shape[1] - img0_shape[1] * gain) / 2, (img1_shape[0] - img0_shape[0] * gain) / 2 
    else:
        gain = ratio_pad[0][0]
        pad = ratio_pad[1]

    coords[0] -= pad[0]
    coords[2] -= pad[0]
    coords[1] -= pad[1]
    coords[3] -= pad[1]

    coords = [coord / gain for coord in coords]

    coords[0] = int(round(np.clip(coords[0], a_min = 0, a_max=img0_shape[1])))
    coords[2] = int(round(np.clip(coords[2], a_min = 0, a_max=img0_shape[1])))
    coords[1] = int(round(np.clip(coords[1], a_min = 0, a_max=img0_shape[0])))
    coords[3] = int(round(np.clip(coords[3], a_min = 0, a_max=img0_shape[0])))

    return coords

def process_detections(detections, input_dims, class_filter=[], class_names=[]):
    w, h = input_dims

    processed_detections = []
    for i, detection in enumerate(detections):

        x1, y1, x2, y2 = int(detection[0]) , int(detection[1]) , int(detection[2]) , int(detection[3])

        coords = scale_coords((input_dims[0],input_dims[1]), [x1,y1,x2,y2], (h,w))
        x1 = coords[0]
        y1 = coords[1]
        x2 = coords[2]
        y2 = coords[3]

        conf = detection[4]

        label_num = detection[-1]

        label = class_names[int(label_num)]
        if label in class_filter:
            processed_detection = [x1,y1,x2,y2,label,conf]
            processed_detections.append(processed_detection)
    return processed_detections


import setuptools
from setuptools import find_packages

long_description = "https://docs.roboflow.com/inference/luxonis-oak"

setuptools.setup(
    name="roboflowoak",  # Replace with your own username
    version="0.0.12",
    author="Roboflow",
    license="GPLv3+",
    author_email="jacob@roboflow.com",
    description="python client for deploying Roboflow models to OAK devices",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://www.roboflow.com",
    install_requires=["requests==2.26.0"],
    packages=find_packages(include=("roboflowoak",)),
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
)
